pub trait Vec4Ext<W> {
// Required method
fn transpose4(
a: Self,
b: Self,
c: Self,
d: Self,
) -> (Self, Self, Self, Self)
where Self: Sized;
}Expand description
Vec4 functions which may not be implemented yet for all Vec4 types. NOTE: functions in this trait may be moved to Vec4 in any patch release. To avoid breakage, import Vec4Ext only together with Vec4, and don’t qualify its methods.
Required Methods
fn transpose4(a: Self, b: Self, c: Self, d: Self) -> (Self, Self, Self, Self)where
Self: Sized,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".